@@ -856,6 +856,77 @@ class Event(Domain):
 
         return DomainFactory.factory('event', obj['event'])
 
+class Authorization(Domain):
+    """
+       A Authorization object.
+    """
+
+
+    @staticmethod
+    def create(params, *auth_args):
+        """
+          Creates an Authorization object
+          @param params: a dict of parameters; valid keys are:
+              - C{amount}:  Amount of the payment (in the smallest unit of your currency). Example: 100 = $1.00USD [min value: 50, max value: 9999900] B{required }
+              - C{card => addressCity}:  City of the cardholder. [max length: 50, min length: 2] 
+              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressLine1}:  Address of the cardholder. [max length: 255] 
+              - C{card => addressLine2}:  Address of the cardholder if needed. [max length: 255] 
+              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 characters in length and only contains numbers or letters. [max length: 9, min length: 3] 
+              - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
+              - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] B{required }
+              - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] B{required }
+              - C{card => name}:  Name as it appears on the card. [max length: 50, min length: 2] 
+              - C{card => number}:  Card number as it appears on the card. [max length: 19, min length: 13] B{required }
+              - C{currency}:  Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. [default: USD] B{required }
+              - C{customer}:  ID of customer. If specified, card on file of customer will be used. 
+              - C{description}:  Free form text field to be used as a description of the payment. This field is echoed back with the payment on any find or list operations. [max length: 1024] 
+              - C{reference}:  Custom reference field to be used with outside systems. 
+              - C{replayId}:  An identifier that can be sent to uniquely identify a payment request to facilitate retries due to I/O related issues. This identifier must be unique for your account (sandbox or live) across all of your payments. If supplied, we will check for a payment on your account that matches this identifier, and if one is found we will attempt to return an identical response of the original request. [max length: 50, min length: 1] 
+              - C{token}:  If specified, card associated with card token will be used. [max length: 255] 
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
+          @return: a Authorization object
+        """
+        return PaymentsApi.create("authorization", auth_args, params)
+
+    def delete(self, *auth_args):
+        """
+            Delete this object
+            @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+                For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+        """
+        return PaymentsApi.delete("authorization", auth_args, self.object_id)
+
+    @staticmethod
+    def list(criteria = None, *auth_args):
+        """
+          Retrieve Authorization objects.
+          @param criteria: a dict of parameters; valid keys are:
+               - C{filter}  Filters to apply to the list. 
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in pagination of the list. This is the start offset of the page. [default: 0] 
+               - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated} C{amount} C{id} C{description} C{paymentDate}.
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @return: an object which contains the list of Authorization objects in the <code>list</code> property and the total number
+                   of objects available for the given criteria in the <code>total</code> property.
+        """
+        return PaymentsApi.list("authorization", auth_args, criteria)
+
+    @staticmethod
+    def find(object_id, *auth_args):
+        """
+          Retrieve a Authorization object from the API
+          @param object_id: ID of object to retrieve
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @return: a Authorization object
+        """
+        return PaymentsApi.find("authorization", auth_args, object_id)
+
 class CardToken(Domain):
     """
        A CardToken object.
@@ -873,7 +944,7 @@ class CardToken(Domain):
               - C{card => addressLine1}:  Address of the cardholder. [max length: 255] 
               - C{card => addressLine2}:  Address of the cardholder if needed. [max length: 255] 
               - C{card => addressState}:  State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
-              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. [max length: 9, min length: 3] 
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. [max length: 9, min length: 3] 
               - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
               - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] B{required }
               - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] B{required }
@@ -942,7 +1013,7 @@ class Coupon(Domain):
         """
           Creates an Coupon object
           @param params: a dict of parameters; valid keys are:
-              - C{amountOff}:  Amount off of the price of the product in minor units in the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 1000 = 10.00 [min value: 1, max value: 99999999] 
+              - C{amountOff}:  Amount off of the price of the product in the smallest units of the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 100 = $1.00USD [min value: 1, max value: 9999900] 
               - C{couponCode}:  Code that identifies the coupon to be used. [min length: 2] B{required }
               - C{description}:  A brief section that describes the coupon. 
               - C{durationInMonths}:  Duration in months that the coupon will be applied after it has first been selected. [min value: 1, max value: 9999] 
@@ -1023,7 +1094,7 @@ class Customer(Domain):
               - C{card => addressLine1}:  Address of the cardholder B{required }
               - C{card => addressLine2}:  Address of the cardholder if needed. B{required }
               - C{card => addressState}:  State code (USPS code) of residence of the cardholder. B{required }
-              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. B{required }
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. B{required }
               - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 B{required }
               - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 B{required }
               - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 B{required }
@@ -1033,7 +1104,7 @@ class Customer(Domain):
               - C{email}:  Email address of the customer B{required }
               - C{name}:  Customer name [min length: 2] B{required }
               - C{reference}:  Reference field for external applications use. 
-              - C{subscriptions => amount}:  Amount of payment in minor units. Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
+              - C{subscriptions => amount}:  Amount of payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
               - C{subscriptions => coupon}:  Coupon associated with the subscription for the customer. 
               - C{subscriptions => currency}:  Currency code (ISO-4217). Must match the currency associated with your account. [default: USD] 
               - C{subscriptions => customer}:  The customer ID to create the subscription for. Do not supply this when creating a customer. 
@@ -1099,7 +1170,7 @@ class Customer(Domain):
 
             - C{card => addressState} State code (USPS code) of residence of the cardholder. B{(required)}
 
-            - C{card => addressZip} Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. B{(required)}
+            - C{card => addressZip} Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. B{(required)}
 
             - C{card => cvc} CVC security code of the card. This is the code on the back of the card. Example: 123 B{(required)}
 
@@ -1166,6 +1237,51 @@ class Invoice(Domain):
     """
 
 
+    @staticmethod
+    def create(params, *auth_args):
+        """
+          Creates an Invoice object
+          @param params: a dict of parameters; valid keys are:
+              - C{currency}:  Currency code (ISO-4217). Must match the currency associated with your account. [max length: 3, min length: 3, default: USD] 
+              - C{customer}:  The customer ID of the customer we are invoicing.  This is optional is a name and email are provided 
+              - C{discountRate}:  The discount percent as a decimal e.g. 12.5.  This is used to calculate the discount amount which is subtracted from the total amount due before any tax is applied. [max length: 6] 
+              - C{dueDate}:  The date invoice payment is due.  If a late fee is provided this will be added to the invoice total is the due date has past. 
+              - C{email}:  The email of the customer we are invoicing.  This is optional if a customer id is provided.  A new customer will be created using the the name and email. 
+              - C{invoiceId}:  User defined invoice id. If not provided the system will generate a numeric id. [max length: 255] 
+              - C{items => amount}:  Amount of the invoice item (the smallest unit of your currency). Example: 100 = $1.00USD [min value: 1, max value: 9999900] B{required }
+              - C{items => description}:  The description of the invoice item. [max length: 1024] 
+              - C{items => invoice}:  The ID of the invoice this item belongs to. 
+              - C{items => product}:  The product this invoice item refers to. B{required }
+              - C{items => quantity}:  Quantity of the item.  This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999, default: 1] 
+              - C{items => reference}:  User defined reference field. [max length: 255] 
+              - C{items => tax}:  The tax ID of the tax charge in the invoice item. 
+              - C{lateFee}:  The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD [max value: 9999900] 
+              - C{memo}:  A memo that is displayed to the customer on the invoice payment screen. [max length: 4000] 
+              - C{name}:  The name of the customer we are invoicing.  This is optional if a customer id is provided.  A new customer will be created using the the name and email. [max length: 50, min length: 2] 
+              - C{note}:  This field can be used to store a note that is not displayed to the customer. [max length: 4000] 
+              - C{reference}:  User defined reference field. [max length: 255] 
+              - C{shippingAddressLine1}:  Address Line 1 where the product should be shipped. [max length: 255] 
+              - C{shippingAddressLine2}:  Address Line 2 where the product should be shipped. [max length: 255] 
+              - C{shippingCity}:  City where the product should be shipped. [max length: 255, min length: 2] 
+              - C{shippingCountry}:  Country where the product should be shipped. [max length: 2, min length: 2] 
+              - C{shippingState}:  State where the product should be shipped. [max length: 2, min length: 2] 
+              - C{shippingZip}:  ZIP code where the product should be shipped. [max length: 9, min length: 5] 
+              - C{type}:  The type of invoice.  One of WEB or MOBILE. [valid values: WEB, MOBILE, default: WEB] 
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
+          @return: a Invoice object
+        """
+        return PaymentsApi.create("invoice", auth_args, params)
+
+    def delete(self, *auth_args):
+        """
+            Delete this object
+            @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+                For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+        """
+        return PaymentsApi.delete("invoice", auth_args, self.object_id)
+
     @staticmethod
     def list(criteria = None, *auth_args):
         """
@@ -1174,7 +1290,7 @@ class Invoice(Domain):
                - C{filter}  Filters to apply to the list. 
                - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
                - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
-               - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{invoiceDate} C{customer} C{amount} C{processedDate}.
+               - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{invoiceDate} C{dueDate} C{datePaid} C{customer} C{status}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @return: an object which contains the list of Invoice objects in the <code>list</code> property and the total number
@@ -1198,7 +1314,49 @@ class Invoice(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{status} New status of the invoice. [valid values: PAID] B{(required)}
+            - C{datePaid} This is the date the invoice was PAID in UTC millis. 
+
+            - C{discountRate} The discount percent as a decimal e.g. 12.5.  This is used to calculate the discount amount which is subtracted from the total amount due before any tax is applied. [max length: 6] 
+
+            - C{dueDate} The date invoice payment is due.  If a late fee is provided this will be added to the invoice total is the due date has past. 
+
+            - C{items => amount} Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] B{(required)}
+
+            - C{items => description} The description of the invoice item. [max length: 1024] 
+
+            - C{items => invoice} The ID of the invoice this item belongs to. 
+
+            - C{items => product} The Id of the product this item refers to. B{(required)}
+
+            - C{items => quantity} Quantity of the item.  This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999, default: 1] 
+
+            - C{items => reference} User defined reference field. [max length: 255] 
+
+            - C{items => tax} The tax ID of the tax charge in the invoice item. 
+
+            - C{lateFee} The late fee amount that will be added to the invoice total is the due date is past due.  Value provided must be in the smallest unit of your currency. Example: 100 = $1.00USD 
+
+            - C{memo} A memo that is displayed to the customer on the invoice payment screen. [max length: 4000] 
+
+            - C{note} This field can be used to store a note that is not displayed to the customer. [max length: 4000] 
+
+            - C{payment} The ID of the payment.  Use this ID to query the /payment API. [max length: 255] 
+
+            - C{reference} User defined reference field. [max length: 255] 
+
+            - C{shippingAddressLine1} The shipping address line 1 for the product. [max length: 255] 
+
+            - C{shippingAddressLine2} The shipping address line 2 for the product. [max length: 255] 
+
+            - C{shippingCity} The shipping city for the product. [max length: 255, min length: 2] 
+
+            - C{shippingCountry} The shipping country for the product. [max length: 2, min length: 2] 
+
+            - C{shippingState} The shipping state for the product. [max length: 2, min length: 2] 
+
+            - C{shippingZip} The shipping ZIP code for the product. [max length: 9, min length: 5] 
+
+            - C{status} New status of the invoice. 
 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1217,10 +1375,13 @@ class InvoiceItem(Domain):
         """
           Creates an InvoiceItem object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] B{required }
-              - C{currency}:  Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] B{required }
-              - C{description}:  Individual items of an invoice 
-              - C{invoice}:  Description of the invoice item B{required }
+              - C{amount}:  Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] B{required }
+              - C{description}:  Individual items of an invoice [max length: 1024] 
+              - C{invoice}:  The ID of the invoice this item belongs to. 
+              - C{product}:  Product ID this item relates to. B{required }
+              - C{quantity}:  Quantity of the item.  This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999, default: 1] 
+              - C{reference}:  User defined reference field. [max length: 255] 
+              - C{tax}:  The tax ID of the tax charge in the invoice item. 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
@@ -1236,22 +1397,6 @@ class InvoiceItem(Domain):
         """
         return PaymentsApi.delete("invoiceItem", auth_args, self.object_id)
 
-    @staticmethod
-    def list(criteria = None, *auth_args):
-        """
-          Retrieve InvoiceItem objects.
-          @param criteria: a dict of parameters; valid keys are:
-               - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
-               - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{amount} C{description} C{invoice}.
-          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
-              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
-          @return: an object which contains the list of InvoiceItem objects in the <code>list</code> property and the total number
-                   of objects available for the given criteria in the <code>total</code> property.
-        """
-        return PaymentsApi.list("invoiceItem", auth_args, criteria)
-
     @staticmethod
     def find(object_id, *auth_args):
         """
@@ -1268,12 +1413,16 @@ class InvoiceItem(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{amount} Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] 
-
-            - C{currency} Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] 
+            - C{amount} Amount of the invoice item in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] 
 
             - C{description} Individual items of an invoice 
 
+            - C{quantity} Quantity of the item.  This total amount of the invoice item is the amount * quantity. [min value: 1, max value: 999999] 
+
+            - C{reference} User defined reference field. 
+
+            - C{tax} The tax ID of the tax charge in the invoice item. 
+
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @return: a InvoiceItem object.
@@ -1291,13 +1440,14 @@ class Payment(Domain):
         """
           Creates an Payment object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] B{required }
+              - C{amount}:  Amount of the payment (in the smallest unit of your currency). Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
+              - C{authorization}:  The ID of the authorization being used to capture the payment. 
               - C{card => addressCity}:  City of the cardholder. [max length: 50, min length: 2] 
               - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] 
               - C{card => addressLine1}:  Address of the cardholder. [max length: 255] 
               - C{card => addressLine2}:  Address of the cardholder if needed. [max length: 255] 
               - C{card => addressState}:  State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
-              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. [max length: 9, min length: 3] 
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. [max length: 9, min length: 3] 
               - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
               - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] B{required }
               - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] B{required }
@@ -1305,8 +1455,10 @@ class Payment(Domain):
               - C{card => number}:  Card number as it appears on the card. [max length: 19, min length: 13] B{required }
               - C{currency}:  Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. [default: USD] B{required }
               - C{customer}:  ID of customer. If specified, card on file of customer will be used. 
-              - C{description}:  Custom naming of payment for external systems to use. 
+              - C{description}:  Free form text field to be used as a description of the payment. This field is echoed back with the payment on any find or list operations. [max length: 1024] 
+              - C{invoice}:  ID of invoice for which this payment is being made. 
               - C{reference}:  Custom reference field to be used with outside systems. 
+              - C{replayId}:  An identifier that can be sent to uniquely identify a payment request to facilitate retries due to I/O related issues. This identifier must be unique for your account (sandbox or live) across all of your payments. If supplied, we will check for a payment on your account that matches this identifier. If found will attempt to return an identical response of the original request. [max length: 50, min length: 1] 
               - C{token}:  If specified, card associated with card token will be used. [max length: 255] 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1342,6 +1494,17 @@ class Payment(Domain):
         """
         return PaymentsApi.find("payment", auth_args, object_id)
 
+    def update(self, *auth_args):
+        """
+          Updates this object
+
+          The properties that can be updated:  
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @return: a Payment object.
+        """
+        return PaymentsApi.update("payment", auth_args, self.object_id, self.to_dict())
+
 class Plan(Domain):
     """
        A Plan object.
@@ -1353,7 +1516,7 @@ class Plan(Domain):
         """
           Creates an Plan object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of payment for the plan in minor units. Example: 1000 = 10.00 [min value: 50, max value: 99999999] B{required }
+              - C{amount}:  Amount of payment for the plan in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] B{required }
               - C{currency}:  Currency code (ISO-4217) for the plan. Must match the currency associated with your account. [default: USD] B{required }
               - C{frequency}:  Frequency of payment for the plan. Example: Monthly B{required }
               - C{name}:  Name of the plan [max length: 50, min length: 2] B{required }
@@ -1423,10 +1586,11 @@ class Refund(Domain):
         """
           Creates an Refund object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the refund in minor units. Example: 1000 = 10.00 [min value: 1, max value: 99999999] B{required }
+              - C{amount}:  Amount of the refund in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 1, max value: 9999900] B{required }
               - C{payment}:  ID of the payment for the refund B{required }
               - C{reason}:  Reason for the refund 
               - C{reference}:  Custom reference field to be used with outside systems. 
+              - C{replayId}:  An identifier that can be sent to uniquely identify a refund request to facilitate retries due to I/O related issues. This identifier must be unique for your account (sandbox or live) across all of your refunds. If supplied, we will check for a refund on your account that matches this identifier. If found we will return an identical response to that of the original request. [max length: 50, min length: 1] 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
@@ -1472,7 +1636,7 @@ class Subscription(Domain):
         """
           Creates an Subscription object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
+              - C{amount}:  Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
               - C{coupon}:  Coupon ID associated with the subscription 
               - C{currency}:  Currency code (ISO-4217). Must match the currency associated with your account. [default: USD] 
               - C{customer}:  Customer that is enrolling in the subscription. 
@@ -1527,7 +1691,7 @@ class Subscription(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{amount} Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
+            - C{amount} Amount of the payment in the smallest unit of your currency. Example: 100 = $1.00USD [min value: 50, max value: 9999900] 
 
             - C{coupon} Coupon being assigned to this subscription 
 
@@ -1549,6 +1713,61 @@ class Subscription(Domain):
         """
         return PaymentsApi.update("subscription", auth_args, self.object_id, self.to_dict())
 
+class Tax(Domain):
+    """
+       A Tax object.
+    """
+
+
+    @staticmethod
+    def create(params, *auth_args):
+        """
+          Creates an Tax object
+          @param params: a dict of parameters; valid keys are:
+              - C{label}:  The label of the tax object. [max length: 255] B{required }
+              - C{rate}:  The tax rate.  Decimal value up three decimal places.  e.g 12.501. [max length: 6] B{required }
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
+          @return: a Tax object
+        """
+        return PaymentsApi.create("tax", auth_args, params)
+
+    def delete(self, *auth_args):
+        """
+            Delete this object
+            @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+                For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+        """
+        return PaymentsApi.delete("tax", auth_args, self.object_id)
+
+    @staticmethod
+    def list(criteria = None, *auth_args):
+        """
+          Retrieve Tax objects.
+          @param criteria: a dict of parameters; valid keys are:
+               - C{filter}  Filters to apply to the list. 
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
+               - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{label}.
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @return: an object which contains the list of Tax objects in the <code>list</code> property and the total number
+                   of objects available for the given criteria in the <code>total</code> property.
+        """
+        return PaymentsApi.list("tax", auth_args, criteria)
+
+    @staticmethod
+    def find(object_id, *auth_args):
+        """
+          Retrieve a Tax object from the API
+          @param object_id: ID of object to retrieve
+          @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
+              For backwards compatibility the public and private keys may be passed instead of an Authentication object.
+          @return: a Tax object
+        """
+        return PaymentsApi.find("tax", auth_args, object_id)
+
 class Webhook(Domain):
     """
        A Webhook object.
