@@ -43,6 +43,9 @@ class Domain:
         if key in self.__dict__:
             return self.__dict__[key]
 
+    def __setitem__(self, key, value):
+        self.__dict__[key] = value
+
     def to_dict(self):
 
         d = dict()
